@@ -5,17 +5,23 @@
 
 #include "TMFunctionThread.h"
 
+#include <QDebug>
+
 TMFunctionThread::TMFunctionThread(QObject *parent) : QThread(parent)
 {
-
+    qDebug() << "Function thread created";
 }
 
 TMFunctionThread::~TMFunctionThread()
 {
+    qDebug() << "Destroying function thread";
     this->wait();
+    qDebug() << "Function thread destroyed";
 }
 
 void TMFunctionThread::run()
 {
+    qDebug() << "Function thread started running";
     result = func();
+    qDebug() << "Function execution completed, result:" << result;
 }
