@@ -12,17 +12,6 @@
 #include <QString>
 #include <QIcon>
 
-// gesture 触控板手势
-#ifdef OS_BUILD_V23
-#define GESTURE_SERVICE          "org.deepin.dde.Gesture"
-#define GESTURE_PATH             "/org/deepin/dde/Gesture"
-#define GESTURE_INTERFACE        "org.deepin.dde.Gesture"
-#else
-#define GESTURE_SERVICE          "com.deepin.daemon.Gesture"
-#define GESTURE_PATH             "/com/deepin/daemon/Gesture"
-#define GESTURE_INTERFACE        "com.deepin.daemon.Gesture"
-#endif
-#define GESTURE_SIGNAL           "Event"
 
 class Utils : public QObject
 {
@@ -126,11 +115,6 @@ public:
      */
     static bool isWayland();
 
-    /**
-     * @return 返回当前桌面环境是否为 Treeland
-     */
-    static bool isTreeland();
-
     /**
      * @brief 设置当前操作的文档名称
      * @param currentFilePath
