@@ -17,6 +17,7 @@
 CentralNavPage::CentralNavPage(DWidget *parent)
     : BaseWidget(parent)
 {
+    qDebug() << "Initializing CentralNavPage...";
     auto tipsLabel = new DLabel(tr("Drag documents here"), this);
     tipsLabel->setAccessibleName("Label_Drag documents here");
     tipsLabel->setAlignment(Qt::AlignHCenter);
@@ -70,6 +71,7 @@ CentralNavPage::CentralNavPage(DWidget *parent)
 //  主题切换
 void CentralNavPage::onThemeChanged()
 {
+    qDebug() << "Theme changed, updating UI";
     auto iconSvg = this->findChild<DLabel *>("iconSvg");
     if (iconSvg) {
         auto plt = Dtk::Gui::DGuiApplicationHelper::instance()->applicationPalette();
